import { ElementRef, EventEmitter, OnInit, AfterViewInit } from '@angular/core';
import { ACService } from './slarn-autocomplete.service';
import { ControlValueAccessor } from '@angular/forms';
export declare class SlarnAutocompleteComponent implements OnInit, AfterViewInit, ControlValueAccessor {
    private _service;
    private _templateVariables;
    private _selectedId;
    _selectedItem: any | Array<SelectedItem>;
    /**
     * list contains code of keys that will trigger the search function
     * and the keys that represent navigation action
     * @link https://www.cambiaresearch.com/articles/15/javascript-char-codes-key-codes
     */
    private _keys;
    private propagateChange;
    private typingTimer;
    private doneTypingInterval;
    displaySuggestions: boolean;
    loadingData: boolean;
    filteredItems: Array<any>;
    autocompleteInput: ElementRef;
    displayAllBtn: ElementRef;
    container: ElementRef;
    spanX: ElementRef;
    configuration: ACLocalConfiguration | ACRemoteConfiguration;
    onItemSelected: EventEmitter<any>;
    constructor(_service: ACService);
    /**
     * Return the selected key(s)
     */
    selectedId: number | string | Array<number | string>;
    /**
     * Filter given value and make sure that the autocomplete gets the correct data
     * to work as expected
     * @param value
     */
    private filterSelectedValue(value);
    /**
     * Check array contain one or many objects
     * @param value
     */
    private arrayHasObject(value);
    /**
     * Return the selected item(s)
     */
    readonly selectedItem: any;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    /**
     * Listener to check if user clicked outside of the autocomplete
     * If he did then we should hide the suggestion list
     * So we make sure that the autocomplete acts like any other list
     */
    checkIfClickedInside: (event: Event) => void;
    /**
     * Clear autocomplete selection
     */
    clearAutocomplete(): void;
    /**
     * Hide or display suggestions list
     */
    toggleDisplaySuggestions(): void;
    /**
     * Init default configuration
     */
    private initConfiguration();
    /**
     * Search and select item by key value
     */
    private searchAndSelectItemFromKey();
    /**
     * Search and select item from data by the value of the key
     * @param data: any[]
     */
    private selectItemFromData(data);
    /**
     * Extract available keys from template
     * will be used to dislay data in the suggestions panel
     */
    private extractTemplateVariables();
    /**
     * fired each time a user press a key
     * @param $event
     */
    onKeyup($event: any): void;
    /**
     * Delete item from selected list
     * And dispatch data
     * @param index
     */
    deleteFromSelectedItems(indexInSelectedItems: number, si: SelectedItem): void;
    /**
     * After key down clear used timer to calculate
     * when user finished typing
     */
    onKeyDown($event: any): void;
    /**
     * Check if this an alphabet or number key
     * @param $event keyup event
     * @return fireKeySearch
     */
    private fireSearchKey($event);
    /**
     * If it's a local configuration then we will search inside the configuration.data object
     * @param word word to search
     * @param data filtered data
     */
    private searchLocally(word, data);
    /**
     * Check if given item exist in _selectedItem array ot not
     * @param item
     */
    private existInSelectedItems(item);
    /**
     * If it's a remote configuration then we get the word and add it to the url
     * before sending the request to the api
     * @param word word to search
     * @param url api url
     * @param selectItemAfterSearch
     */
    private searchRemotely(word, url, selectItemAfterSearch?);
    /**
     * Build view with data based on the given template
     * @param object
     * @return string built view
     */
    buildView(object: any): string;
    /**
     * Extract the correct value from the multidimensional object
     * @param keysString: string with keys separated by dots
     * @param object
     * @returns correct value
     */
    private extractValue(keysString, object);
    /**
     * Triggered after a user select a suggestion
     * @param item selected item from the list
     * @param index the index of the item in the filtered items
     */
    performSelection(item: any, index: number): void;
    /**
     * Dispatch data to external components
     */
    private dispatchData();
    /**
     * Extract items from _selectedItems
     */
    private extractSelectedItems();
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    writeValue(value: any): void;
}
/**
 * Suggestion component for Autocomplete
 */
export declare class SlarnAutocompleteSuggestionComponent implements OnInit {
    item: any;
    onSuggestionClicked: EventEmitter<any>;
    constructor();
    ngOnInit(): void;
    selectItem(): void;
}
/**
 * AutoComplete configuration
 */
export interface Configuration {
    /**
     * key will be stored in the input
     * must be the unique value of the object (ex: id)
     * will be used to search item and when sending form
     */
    key: string;
    value: string;
    template?: string;
    name?: string;
    placeHolder?: string;
    multiple?: boolean;
    loadingView?: string;
    emptyListView?: string;
}
/**
 * Remote configuration used when you want to work remotely with an api
 */
export interface ACRemoteConfiguration extends Configuration {
    url: string;
}
/**
 * Local configuration: used if you want to pass data explicitly to the AutoComplete
 */
export interface ACLocalConfiguration extends Configuration {
    data: Array<any>;
}
/**
 * We will use this object to store selected items
 */
export interface SelectedItem {
    elem: any;
    indexInFilteredItems: number;
}
